/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome Team Members:
 *   Jean Van Wyk <jeanvanwyk@iname.com>
 *   Jeffrey S. Morgan <jeffrey.morgan@bristolwest.com>
 *   Dan Bornstein <danfuzz@milk.com>
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 *
 * This file was orriginally generated by the Java-GNOME Code Generator
 * Please do not modify the code that is identified as generated.  Also,
 * please insert your code above the generated code.
 *
 * Generation date: 2002-08-02 09:30:42 EDT
 */

package org.gnu.gtk;

import java.util.Vector;

import org.gnu.glib.EventMap;
import org.gnu.glib.GObject;
import org.gnu.glib.Type;
import org.gnu.gtk.event.TreeSelectionEvent;
import org.gnu.gtk.event.TreeSelectionListener;
import org.gnu.gtk.event.GtkEventType;

/**
 * The TreeSelection object is a helper object to manage the selection for a 
 * {@link TreeView} widget. The TreeSelection object is automatically created 
 * when a newTreeView widget is created, and cannot exist independentally of 
 * this widget. The primary reason the TreeSelection objects exists is for 
 * cleanliness of code and API. That is, there is no conceptual reason all 
 * these functions could not be methods on the TreeView widget instead of a 
 * separate function.
 *
 * <p>The TreeSelection object is gotten from a TreeView by calling 
 * {@link TreeView#getSelection()}. It can be manipulated to check the 
 * selection status of the tree, as well as select and deselect individual 
 * rows. Selection is done completely view side. As a result, multiple views 
 * of the same model can have completely different selections. Additionally, 
 * you cannot change the selection of a row on the model that is not currently 
 * displayed by the view without expanding its parents first.
 *
 * <p>One of the important things to remember when monitoring the selection 
 * of a view is that the "changed" event is mostly a hint. That is, it may only 
 * emit one signal when a range of rows is selected. Additionally, it may on 
 * occasion emit a "changed" event when nothing has happened (mostly as a 
 * result of programmers calling selectRow on an already selected row).
 * @see TreeView
 */
public class TreeSelection extends GObject {
	/**
	 * constructs a new selection using handle from a native function..
	 */
	protected TreeSelection(int h) {
		handle = h;
		initializeEventHandlers();
	}

	// TODO: GtkTreeSelectionFunc ()
	// gtk_tree_selection_set_select_function ()
	// gtk_tree_selection_get_user_data ()


	/**
	 * Calls the forEach method of the specified class for every selected value.
	 */
	public void forEachSelected(TreeSelectionForEach implementor) {
		curForEach = implementor;
		startForEach(handle, this);
	}

	private static native void startForEach(int handle, Object o);

	private TreeSelectionForEach curForEach;
	/** This is called from the jni code to operate the foreach method */
	private void doEach(int model, int path, int iter) {
		curForEach.forEach(new TreeModel(model), new TreePath(path), new TreeIter(iter));
	}

	/**
	 * Sets the selection mode of the selection. If the previous type was 
	 * SelectionMode.MULTIPLE, then the anchor is kept selected, if it was 
	 * previously selected.
	 * @param mode The selection mode to use.
	 */
	public void setMode(SelectionMode mode) {
		gtk_tree_selection_set_mode(handle, mode.getValue());
	}

	/**
	 * Returns the {@link TreeView} associated with the selection.
	 * @return Associated widget
	 */
	public TreeView getTreeView() {
		return new TreeView(gtk_tree_selection_get_tree_view(handle));
	}

	/**
	 * Select the row at path.
	 * @param path The path to be selected.
	 */
	public void select(TreePath path) {
		gtk_tree_selection_select_path(handle, path.getHandle());
	}

	/**
	 * Unselects the row at path.
	 * @param path The path to be deselected
	 */
	public void unselect(TreePath path) {
		gtk_tree_selection_unselect_path(handle, path.getHandle());
	}

	/**
	 * Returns TRUE if the row pointed to by path is currently selected. If 
	 * path does not point to a valid location, FALSE is returned
	 * @param path A patch to check the selection on
	 * @return True if the path is selected.
	 */
	public boolean getSelected(TreePath path) {
		return gtk_tree_selection_path_is_selected(handle, path.getHandle());
	}

	/**
	 * Selects the specified iterator.
	 * @param iter The {@link TreeIter} to be selected.
	 */
	public void select(TreeIter iter) {
		gtk_tree_selection_select_iter(handle, iter.getHandle());
	}

	/**
	 * Unselects the specified iterator.
	 * @param iter The {@link TreeIter} to be unselected.
	 */
	public void unselect(TreeIter iter) {
		gtk_tree_selection_unselect_iter(handle, iter.getHandle());
	}

	/**
	 * Returns TRUE if the row pointed to by iter is currently selected.
	 * @param iter The iter to test the selection of
	 * @return true if the iter is selected.
	 */
	public boolean getSelected(TreeIter iter) {
		return gtk_tree_selection_iter_is_selected(handle, iter.getHandle());
	}

	/**
	 * Selects all the nodes. Mode must be set to SelectionMode.MULTIPLE
	 */
	public void selectAll() {
		gtk_tree_selection_select_all(handle);
	}

	/**
	 * Unselects all the nodes.
	 */
	public void unselectAll() {
		gtk_tree_selection_unselect_all(handle);
	}

	/**
	 * Selects a range of nodes, determined by startPath and endPath inclusive.
	 * @param startPath The initial node of the range.
	 * @param endPath The final node of the range.
	 */
	public void select(TreePath startPath, TreePath endPath) {
		gtk_tree_selection_select_range(handle, startPath.getHandle(), endPath.getHandle());
	}

	/**
	 * Returns an array of rows which are currently selected
	 * @since 2.2
	 */
	public TreePath[] getSelectedRows(){
		// TODO
		/* gtk_tree_selection_get_selected_rows ()

		GList*      gtk_tree_selection_get_selected_rows
													(GtkTreeSelection *selection,
													 GtkTreeModel **model);

		Creates a list of path of all selected rows. Additionally, if you are
		planning on modifying the model after calling this function, you may
		want to convert the returned list into a list of GtkTreeRowReferences.
		To do this, you can use gtk_tree_row_reference_new_proxy().

		To free the return value, use:

		g_list_foreach (list, gtk_tree_path_free, NULL);
		g_list_free (list);

		selection :	A GtkTreeSelection.
		model :	A pointer to set to the GtkTreeModel, or NULL.
		Returns :	A GList containing a GtkTreePath for each selected row.

		Since 2.2 
		*/
		return new TreePath[] {null};
	}

	/**
	 * Returns the number of rows that have been selected.
	 * @since 2.2
	 */
	public int countRows(){
		/* TODO
		 * gtk_tree_selection_count_selected_rows ()

		gint        gtk_tree_selection_count_selected_rows
													(GtkTreeSelection *selection);

		Returns the number of rows that have been selected in tree.

		selection :	A GtkTreeSelection.
		Returns :	The number of rows selected.
		*/
		return -1;
	}

	///////////////////////////////////////////////////////////////////////////////
	// EVENTS - the Changed signal.
	//
	/** listeners for selection changing */
	private Vector selectionListeners = null;

	/** 
	 * Register an object to handle Selection change events which are emitted
	 * whenever the selection has (possibly) changed
	 * @see org.gnu.gtk.event.TreeSelectionListener
	 */
	public void addListener(TreeSelectionListener listener) {
		// Don't add the listener a second time if it is in the Vector.
		int i = Widget.findListener(selectionListeners, listener);
		if (i == -1) {
			if (null == selectionListeners) {
				selectionListeners = new Vector();
			}
			selectionListeners.addElement(listener);
		}
	}

	/**
	 * Removes a listener
	 * @see #addListener(TreeSelectionListener)
	 */
	public void removeListener(TreeSelectionListener listener) {
		int i = Widget.findListener(selectionListeners, listener);
		if (i > -1) {
			selectionListeners.remove(i);
		}
		if (0 == selectionListeners.size()) {
			selectionListeners = null;
		}
	}

	protected void fireSelectionEvent(TreeSelectionEvent event) {
		if (null == selectionListeners) {
			return;
		}
		int size = selectionListeners.size();
		int i = 0;
		while (i < size) {
			TreeSelectionListener bl = (TreeSelectionListener)selectionListeners.elementAt(i);
			bl.selectionChangedEvent(event);
			i++;
		}
	}
	private void handleChanged() {
		fireSelectionEvent(new TreeSelectionEvent(this));
	}

	protected void initializeEventHandlers() {
	    evtMap.initialize(this);
	}

        public Class getEventListenerClass(String signal) {
	    return evtMap.getListenerClass(signal);
	}

        public GtkEventType getEventType(String signal) {
	    return evtMap.getEventType(signal);
	}

        private static EventMap evtMap = new EventMap();
        static {
		addEvents(evtMap);
	}

	private static void addEvents(EventMap evtMap) {
	    evtMap.addEvent("changed", "handleChanged",
			    TreeSelectionEvent.Type.CHANGED,
			    TreeSelectionListener.class);
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_tree_selection_get_type());
	}

	/****************************************
	 * BEGINNING OF GENERATED CODE
	 ****************************************/
	native static final protected int gtk_tree_selection_get_type();
	native static final protected void gtk_tree_selection_set_mode(int selection, int type);
	native static final protected int gtk_tree_selection_get_mode(int selection);
	native static final protected int gtk_tree_selection_get_user_data(int selection);
	native static final protected int gtk_tree_selection_get_tree_view(int selection);
	native static final protected boolean gtk_tree_selection_get_selected(int selection, int[] model, int iter);
	native static final protected void gtk_tree_selection_select_path(int selection, int path);
	native static final protected void gtk_tree_selection_unselect_path(int selection, int path);
	native static final protected void gtk_tree_selection_select_iter(int selection, int iter);
	native static final protected void gtk_tree_selection_unselect_iter(int selection, int iter);
	native static final protected boolean gtk_tree_selection_path_is_selected(int selection, int path);
	native static final protected boolean gtk_tree_selection_iter_is_selected(int selection, int iter);
	native static final protected void gtk_tree_selection_select_all(int selection);
	native static final protected void gtk_tree_selection_unselect_all(int selection);
	native static final protected void gtk_tree_selection_select_range(int selection, int startPath, int endPath);
	/****************************************
	 * END OF GENERATED CODE
	 ****************************************/
}
